==> cdk-datalake-constructs-0.0.34.tar.gz: package/lib/etl/glue-job-ops.d.ts <==
import * as cloudwatch from '@aws-cdk/aws-cloudwatch';
import * as cdk from '@aws-cdk/core';
import { GlueJob } from './glue-job';
/**
 * @experimental
 */
export interface IGlueOpsProperties {
    /**
     * @experimental
     */
    job: GlueJob;
    /**
     * @experimental
     */
    jvmHeapSizeExceeding80percent?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    jvmHeapSizeExceeding90percent?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    metricExecutionFailure?: cloudwatch.CreateAlarmOptions;
    /**
     * @experimental
     */
    metricAllExecutionAttemptsFailed?: cloudwatch.CreateAlarmOptions;
}
/**
 * @experimental
 */
export declare class GlueJobOps extends cdk.Construct {
    /**
     * @experimental
     */
    readonly job: GlueJob;
    /**
     * @experimental
     */
    dashboard: cloudwatch.Dashboard;
    /**
     * @experimental
     */
    readonly jvmHeapSizeExceeding80PercentAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly jvmHeapSizeExceeding90PercentAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly metricExecutionFailureAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly metricAllExecutionAttemptsFailedAlarm: cloudwatch.Alarm;
    /**
     * @experimental
     */
    readonly alarmsSev2: cloudwatch.Alarm[];
    /**
     * @experimental
     */
    readonly alarmsSev3: cloudwatch.Alarm[];
    /**
     * @experimental
     */
    constructor(scope: cdk.Construct, id: string, props: IGlueOpsProperties);
    private addWidgets;
    private setupDashboard;
    private alarmWidget;
}

==> cdk-datalake-constructs-0.0.44.tar.gz: package/lib/etl/glue-job-ops.d.ts <==
import * as cloudwatch from 'aws-cdk-lib/aws-cloudwatch';
import { Construct } from 'constructs';
import { GlueJob } from './glue-job';
/**
 * @stability stable
 */
export interface IGlueOpsProperties {
    /**
     * @stability stable
     */
    job: GlueJob;
    /**
     * @stability stable
     */
    jvmHeapSizeExceeding80percent?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    jvmHeapSizeExceeding90percent?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    metricExecutionFailure?: cloudwatch.CreateAlarmOptions;
    /**
     * @stability stable
     */
    metricAllExecutionAttemptsFailed?: cloudwatch.CreateAlarmOptions;
}
/**
 * @stability stable
 */
export declare class GlueJobOps extends Construct {
    /**
     * @stability stable
     */
    readonly job: GlueJob;
    /**
     * @stability stable
     */
    dashboard: cloudwatch.Dashboard;
    /**
     * @stability stable
     */
    readonly jvmHeapSizeExceeding80PercentAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly jvmHeapSizeExceeding90PercentAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly metricExecutionFailureAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly metricAllExecutionAttemptsFailedAlarm: cloudwatch.Alarm;
    /**
     * @stability stable
     */
    readonly alarmsSev2: cloudwatch.Alarm[];
    /**
     * @stability stable
     */
    readonly alarmsSev3: cloudwatch.Alarm[];
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: IGlueOpsProperties);
    private addWidgets;
    private setupDashboard;
    private alarmWidget;
}
